@@ -28,6 +28,9 @@ class SharedBackendConf(SharedBackendConfUtils):
     def backendClusterMode(self):
         return self._jconf.backendClusterMode()
 
+    def cloudName(self):
+        return self._get_option(self._jconf.cloudName())
+
     def isH2OReplEnabled(self):
         return self._jconf.isH2OReplEnabled()
 
@@ -79,15 +82,9 @@ class SharedBackendConf(SharedBackendConfUtils):
     def autoFlowSsl(self):
         return self._jconf.autoFlowSsl()
 
-    def h2oNodeLogLevel(self):
-        return self._jconf.h2oNodeLogLevel()
-
     def logLevel(self):
         return self._jconf.logLevel()
 
-    def h2oNodeLogDir(self):
-        return self._get_option(self._jconf.h2oNodeLogDir())
-
     def logDir(self):
         return self._get_option(self._jconf.logDir())
 
@@ -115,18 +112,12 @@ class SharedBackendConf(SharedBackendConfUtils):
     def internalPortOffset(self):
         return self._jconf.internalPortOffset()
 
-    def nodeBasePort(self):
-        return self._jconf.nodeBasePort()
-
     def basePort(self):
         return self._jconf.basePort()
 
     def mojoDestroyTimeout(self):
         return self._jconf.mojoDestroyTimeout()
 
-    def nodeExtraProperties(self):
-        return self._get_option(self._jconf.nodeExtraProperties())
-
     def extraProperties(self):
         return self._get_option(self._jconf.extraProperties())
 
@@ -145,18 +136,6 @@ class SharedBackendConf(SharedBackendConfUtils):
     def clientIp(self):
         return self._get_option(self._jconf.clientIp())
 
-    def clientIcedDir(self):
-        return self._get_option(self._jconf.clientIcedDir())
-
-    def h2oClientLogLevel(self):
-        return self._jconf.h2oClientLogLevel()
-
-    def h2oClientLogDir(self):
-        return self._get_option(self._jconf.h2oClientLogDir())
-
-    def clientBasePort(self):
-        return self._jconf.clientBasePort()
-
     def clientWebPort(self):
         return self._jconf.clientWebPort()
 
@@ -169,9 +148,6 @@ class SharedBackendConf(SharedBackendConfUtils):
     def clientFlowBaseurlOverride(self):
         return self._get_option(self._jconf.clientFlowBaseurlOverride())
 
-    def clientExtraProperties(self):
-        return self._get_option(self._jconf.clientExtraProperties())
-
     def runsInExternalClusterMode(self):
         return self._jconf.runsInExternalClusterMode()
 
@@ -208,9 +184,6 @@ class SharedBackendConf(SharedBackendConfUtils):
     def icedDir(self):
         return self._get_option(self._jconf.icedDir())
 
-    def cloudName(self):
-        return self._get_option(self._jconf.cloudName())
-
     def restApiTimeout(self):
         return self._jconf.restApiTimeout()
 
@@ -338,18 +311,10 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setAutoFlowSslDisabled()
         return self
 
-    def setH2ONodeLogLevel(self, value):
-        self._jconf.setH2ONodeLogLevel(value)
-        return self
-
     def setLogLevel(self, value):
         self._jconf.setLogLevel(value)
         return self
 
-    def setH2ONodeLogDir(self, value):
-        self._jconf.setH2ONodeLogDir(value)
-        return self
-
     def setLogDir(self, value):
         self._jconf.setLogDir(value)
         return self
@@ -390,10 +355,6 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setInternalPortOffset(value)
         return self
 
-    def setNodeBasePort(self, value):
-        self._jconf.setNodeBasePort(value)
-        return self
-
     def setBasePort(self, value):
         self._jconf.setBasePort(value)
         return self
@@ -402,10 +363,6 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setMojoDestroyTimeout(value)
         return self
 
-    def setNodeExtraProperties(self, value):
-        self._jconf.setNodeExtraProperties(value)
-        return self
-
     def setExtraProperties(self, value):
         self._jconf.setExtraProperties(value)
         return self
@@ -438,22 +395,6 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setClientIp(value)
         return self
 
-    def setClientIcedDir(self, value):
-        self._jconf.setClientIcedDir(value)
-        return self
-
-    def setH2OClientLogLevel(self, value):
-        self._jconf.setH2OClientLogLevel(value)
-        return self
-
-    def setH2OClientLogDir(self, value):
-        self._jconf.setH2OClientLogDir(value)
-        return self
-
-    def setClientBasePort(self, value):
-        self._jconf.setClientBasePort(value)
-        return self
-
     def setClientWebPort(self, value):
         self._jconf.setClientWebPort(value)
         return self
@@ -478,10 +419,6 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setClientCheckRetryTimeout(value)
         return self
 
-    def setClientExtraProperties(self, value):
-        self._jconf.setClientExtraProperties(value)
-        return self
-
     def setVerifySslCertificates(self, value):
         self._jconf.setVerifySslCertificates(value)
         return self
