@@ -29,6 +29,7 @@ class H2ODRFRegressor(H2ODRF):
                  calibrationDataFrame=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
@@ -84,12 +85,14 @@ class H2ODRFRegressor(H2ODRF):
                  stoppingTolerance=0.001,
                  gainsliftBins=-1,
                  customMetricFunc=None,
-                 exportCheckpointsDir=None):
+                 exportCheckpointsDir=None,
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2ODRF, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.regression.H2ODRFRegressor", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
